/*
 * sanity.h
 *	Misc convenience functions/macros.
 *
 * Copyright (C) 1997 Eric A. Howe
 *
 * This library is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *   Authors:	Matthew D. Francey
 *		Eric A. Howe (mu@trends.net)
 */
#ifndef	WLIB_SANITY_H
#define	WLIB_SANITY_H
MU_HID(wlib_sanity_h, "$Mu: wlib/wlib/sanity.h,v 1.3 $")

CDECLS_BEGIN
/*
 * This is the same as XFreePixmap() but it can deal with None pixmaps.
 * I got sick of all the silly "if this isn't dead, kill it" code, if
 * something is already dead, then killing it again should be very
 * easy so why should I have to check for life-signs all the time?
 * For convenience, this function always returns "None".
 */
extern	Pixmap	wl_free_pixmap(Display *, Pixmap);
CDECLS_END

#endif
